/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
import { ChangeDetectorRef, ElementRef, EventEmitter, InjectionToken, OnDestroy } from '@angular/core';
import { MatNotificationIntl } from './notification-intl';
import * as i0 from "@angular/core";
/** Default `mat-notification` options that can be overridden. */
export interface MatNotificationDefaultOptions {
    /** Amount of time in milliseconds to show the transient notification */
    timer: number;
}
export interface MatNotificationItem {
    state: MatNotificationState;
    message: string;
    isOpen: boolean;
    buttonText?: string;
    timer?: number;
}
export interface MatNotificationEvent {
    type: MatNotificationType;
    item: MatNotificationItem;
}
export declare type MatNotificationState = 'default' | 'error' | 'info' | 'success' | 'warning';
export declare type MatNotificationType = 'persistent' | 'transient';
/** Injection token to be used to override the default options for `mat-notification`. */
export declare const MAT_NOTIFICATION_DEFAULT_OPTIONS: InjectionToken<MatNotificationDefaultOptions>;
/** @docs-private */
export declare function MAT_NOTIFICATION_DEFAULT_OPTIONS_FACTORY(): MatNotificationDefaultOptions;
/** MAT Transient and Persistent Notifications */
export declare class MatNotification implements OnDestroy {
    _intl: MatNotificationIntl;
    private _changeDetectorRef;
    _elementRef: ElementRef;
    private defaults;
    protected _uid: string;
    /** @docs-private */
    notificationIds: {
        persistent: string;
        transient: string;
    };
    nextNotificationId: number;
    private _intlChanges;
    /** Aria-label attribute internationalized strings. */
    /** @docs-private */
    uniqueNotificationId: string;
    /**
     * Data pertaining to the Notifications currently in scope.
     * persistentData: { state, message, isOpen, buttonText }
     * transientData: { state, message, isOpen, buttonText, timer }
     */
    readonly notificationData: any;
    /**
     * Close timer reference.
     */
    private closeTimer;
    get id(): string;
    set id(value: string);
    protected _id: string;
    /** @docs-private */
    notificationButton: ElementRef;
    /**
     * Event emitter for notification done displaying
     */
    notificationDone: EventEmitter<MatNotificationEvent>;
    /**
     * Event emitter for notification button click
     */
    notificationButtonClicked: EventEmitter<MatNotificationEvent>;
    constructor(_intl: MatNotificationIntl, _changeDetectorRef: ChangeDetectorRef, _elementRef: ElementRef, defaults: MatNotificationDefaultOptions);
    ngOnDestroy(): void;
    /**
     * Returns Aria-label attribute internationalized strings for given notification state.
     * @param state MatNotificationState
     * @returns string
     */
    getStateLabel(state: MatNotificationState): string;
    /**
     * Returns icon name for given notification state.
     * @param state MatNotificationState
     * @returns string
     */
    getStateIcon(state: MatNotificationState): string | null;
    /**
     * Sets up notification object within container
     * @param message Message for the Notification
     * @param type (optional) Default is MatNotificationTypes.Persistent. Use MatNotificationTypes enum
     * @param notificationState (optional) Default is MatNotificationStates.Default. Use MatNotificationStates enum
     * @param buttonText (optional) Specifying the Button text enables the notification button
     * @param timer (optional) Used in Transient notification for how long to display message in milliseconds.
     * If less than 3000 will default to 3000. Can be configured globally through the `MAT_NOTIFICATION_DEFAULT_OPTIONS` token.
     */
    setNotification(message: string, type?: MatNotificationType, notificationState?: MatNotificationState, buttonText?: string, timer?: number): void;
    /**
     * Close notification by type within the container.
     *
     * @param type Specify the type fo notification to close.
     */
    close(type: MatNotificationType): void;
    /**
     * Closes all types of notifications within the container.
     */
    closeAll(): void;
    /** @docs-private */
    buttonClickedHandler(event: MatNotificationEvent): void;
    /** @docs-private */
    closeButtonClickHandler(): void;
    /** @docs-private */
    closeOnTimer(timer: number): void;
    /** @docs-private */
    slideEnd(event: any): void;
    /** @docs-private */
    closeNotification(type: MatNotificationType): void;
    /** @docs-private */
    private getNotificationKey;
    /** Returns list of classes for notification types */
    getNotificationClasses(type: MatNotificationType, state: MatNotificationState): object;
    static ɵfac: i0.ɵɵFactoryDeclaration<MatNotification, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatNotification, "mat-notification", never, { "id": "id"; }, { "notificationDone": "notificationDone"; "notificationButtonClicked": "notificationButtonClicked"; }, never, never>;
}
