/*!
 * Copyright Veritas Technologies LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://stash.veritas.com/projects/VDL/repos/vdl-angular-nx/browse/LICENSE
 */
import { Directionality } from '@angular/cdk/bidi';
import { DragDrop, DragRef, Point } from '@angular/cdk/drag-drop';
import { AfterViewInit, ElementRef, EventEmitter, OnDestroy, QueryList, Renderer2 } from '@angular/core';
import { MatColumnDef } from './cell';
import { MatTable } from './table';
import * as i0 from "@angular/core";
export interface MatTableColumnResizeValues {
    resizeColumnTableRef: MatResizableColumnsTable;
    columnDef: MatColumnDef;
    columnElementRef: ElementRef;
    cellPadding: {
        left: number;
        right: number;
    };
    dragData: {
        source: DragRef<any>;
        pointerPosition?: {
            x: number;
            y: number;
        };
        event?: MouseEvent | TouchEvent;
        distance?: Point;
        delta?: {
            x: 0 | 1 | -1;
            y: 0 | 1 | -1;
        };
    };
    previousWidth: number;
    newWidth?: number;
}
export interface MatTableColumnWidth {
    columnName: string;
    width: number | undefined;
}
/**
 * Specificity Depth type
 *
 * SpecificityDepth values are as follows:
 *   1 - Used for setting the initial column widths in table (Not used for specifying set widths for columns)
 *   2 - Used for setting predefined set widths for columns
 *   3 - Used for column resizing
 */
export declare type MatTableColumnSpecificityDepth = 1 | 2 | 3;
/**
 * Marks the column as resizable. Only those columns which are designated with
 * this directive are resizable.
 *
 * Columns marked with this directive will have a resize handle on hover allowing
 * them to be sized in either direction.
 */
export declare class MatResizableTableColumn implements AfterViewInit, OnDestroy {
    private elementRef;
    private tableRef;
    private dragDropService;
    private columnDef;
    /** Reference to the drag */
    dragRef: DragRef;
    private _previousWidth;
    private _newWidth;
    private _isResizing;
    private _cellPadding;
    /** Subscription to the Directionality change EventEmitter. */
    private _dirChangeSubscription;
    private isRtl;
    /** Minimum drag width for column */
    minDragWidth: number;
    /** Column Resize started event */
    columnResizeStarted: EventEmitter<MatTableColumnResizeValues>;
    /** Column Resize moved event */
    columnResizeMoved: EventEmitter<MatTableColumnResizeValues>;
    /** Column Resize ended event */
    columnResizeEnded: EventEmitter<MatTableColumnResizeValues>;
    columnResizeInit: EventEmitter<MatResizableTableColumn>;
    constructor(elementRef: ElementRef<HTMLElement>, tableRef: MatResizableColumnsTable, dragDropService: DragDrop, columnDef: MatColumnDef, dir: Directionality);
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    /**
     * Gets the width of the column less the padding.
     */
    private getCellPadding;
    /** Returns elementRef for resizableColumn  */
    getElement(): ElementRef<HTMLElement>;
    static ɵfac: i0.ɵɵFactoryDeclaration<MatResizableTableColumn, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MatResizableTableColumn, "[matResizableTableColumn]", ["matResizableTableColumn"], { "minDragWidth": "minDragWidth"; }, { "columnResizeStarted": "columnResizeStarted"; "columnResizeMoved": "columnResizeMoved"; "columnResizeEnded": "columnResizeEnded"; "columnResizeInit": "columnResizeInit"; }, never>;
}
/**
 * Directive added to VDL Table with resizable columns. Provides functions for managing
 * columns
 */
export declare class MatResizableColumnsTable implements AfterViewInit, OnDestroy {
    private tableElementRef;
    tableRef: MatTable<any>;
    private renderer;
    /** @docs-private */
    uniqueId: number;
    uniqueClassName: string;
    private _stylesheet;
    private _stylesheetId;
    private _isHtmlTable;
    private _specificityDepthsSet;
    /** Subscription to the Directionality change EventEmitter. */
    private _dirChangeSubscription;
    /** Is table in RTL */
    isRtl: boolean;
    columnDefs: QueryList<MatColumnDef>;
    constructor(tableElementRef: ElementRef<HTMLElement>, tableRef: MatTable<any>, renderer: Renderer2, dir: Directionality);
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    /**
     * Gets the width of the supplied element less the padding.
     *
     * @param columnName column name
     * @returns column width
     */
    getColumnWidth(columnName: string): number | undefined;
    /**
     * Sets the column widths given an array of columns with widths
     *
     * @param specificityDepth specificity depth for css classes
     * @param columnWidths array that specifies the column and width changes
     */
    setColumnWidths(specificityDepth: MatTableColumnSpecificityDepth, columnWidths: MatTableColumnWidth[]): void;
    /**
     * Creates or replaces a rule for the column in the stylesheet.
     *
     * SpecificityDepth values are as follows:
     *   1 - Used for setting the initial column widths in table (Not used for specifying set widths for columns)
     *   2 - Used for setting predefined set widths for columns
     *   3 - Used for column resizing
     *
     * @param columnName for component based tables, needed to set up the css class specification
     * @param specificityDepth specificity depth for css classes
     * @param width width in pixels for the supplied element
     */
    private addOrReplaceRule;
    /**
     * Deletes all classes in the stylesheet set at a given specificity
     *
     * @param specificityDepth Specificity depth of classes to delete
     */
    resetStylesheetSpecificity(specificityDepth: MatTableColumnSpecificityDepth): void;
    private setColumnStylesheet;
    static ɵfac: i0.ɵɵFactoryDeclaration<MatResizableColumnsTable, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MatResizableColumnsTable, "[matResizableColumnsTable]", ["matResizableColumnsTable"], {}, {}, ["columnDefs"]>;
}
//# sourceMappingURL=column-resize.d.ts.map